Convolution Operators
=====================

Base class for graph convolution operators. 

.. automodule:: pycgsp.linop.conv
   :special-members: __init__
   
   .. autosummary::
   
      GraphConvolution   



